@@ -2,17 +2,21 @@ from __future__ import absolute_import
 
 import typing
 
+from appium.webdriver import Remote as AppiumWebDriver
+
 from applitools.common import EyesError, MatchResult, logger
 from applitools.common.selenium import Configuration
 from applitools.common.utils import argument_guard
+from applitools.common.utils.compat import basestring
 from applitools.common.utils.general_utils import all_fields, proxy_to
 from applitools.core.eyes_base import DebugScreenshotsAbstract
 from applitools.core.eyes_mixins import EyesConfigurationMixin
+from applitools.core.feature import Feature
 from applitools.core.locators import LOCATORS_TYPE, VisualLocatorSettings
 from applitools.core.server_connector import ServerConnector
 from applitools.selenium import ClassicRunner, eyes_selenium_utils
 
-from .fluent import Target
+from .fluent import SeleniumCheckSettings, Target
 from .locators import SeleniumVisualLocatorsProvider
 from .selenium_eyes import SeleniumEyes
 from .visual_grid import VisualGridEyes, VisualGridRunner
@@ -37,7 +41,6 @@ if typing.TYPE_CHECKING:
         UnscaledFixedCutProvider,
     )
 
-    from .fluent import SeleniumCheckSettings
     from .frames import FrameChain
     from .webelement import EyesWebElement
 
@@ -374,6 +377,7 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
         if not self._is_visual_grid_eyes:
             self.configure.send_dom = value
 
+    @typing.overload
     def check(self, name, check_settings):
         # type: (Text, SeleniumCheckSettings) -> MatchResult
         """
@@ -381,15 +385,36 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
 
         :param name: The name of the tag.
         :param check_settings: target which area of the window to check.
-        :return: The match results.
         """
+        pass
+
+    @typing.overload
+    def check(self, check_settings):
+        # type: (SeleniumCheckSettings) -> None
+        """
+        Takes a snapshot and matches it with the expected output.
+
+        :param check_settings: target which area of the window to check.
+        """
+        pass
+
+    def check(self, check_settings, name=None):
+        if isinstance(name, SeleniumCheckSettings) or isinstance(
+            check_settings, basestring
+        ):
+            check_settings, name = name, check_settings
+        if check_settings is None:
+            check_settings = Target.window()
+        if name:
+            check_settings = check_settings.with_name(name)
+
         if self.configure.is_disabled:
             logger.info("check(): ignored (disabled)")
             return MatchResult()
         if not self.is_open:
             self.abort()
             raise EyesError("you must call open() before checking")
-        return self._current_eyes.check(name, check_settings)
+        return self._current_eyes.check(check_settings)
 
     def check_window(self, tag=None, match_timeout=-1, fully=None):
         # type: (Optional[Text], int, Optional[bool]) -> MatchResult
@@ -400,7 +425,6 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
         :param tag: An optional tag to be associated with the snapshot.
         :param match_timeout:  The amount of time to retry matching (milliseconds)
         :param fully: Defines that the screenshot will contain the entire window.
-        :return: The match results.
         """
         logger.debug("check_window('%s')" % tag)
         return self.check(tag, Target.window().timeout(match_timeout).fully(fully))
@@ -414,7 +438,6 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
                 name/id as would be used in a call to driver.switch_to.frame()).
         :param tag: An optional tag to be associated with the match.
         :param match_timeout: The amount of time to retry matching. (Milliseconds)
-        :return: The match results.
         """
         logger.debug("check_frame('%s')" % tag)
         return self.check(
@@ -440,12 +463,34 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
         :param match_timeout: Timeout for the visual validation checkpoint
                               (milliseconds).
         :param stitch_content: If `True`, stitch the internal content of the region
-        :return: The match results.
         """
         logger.debug("check_region('%s')" % tag)
         return self.check(
             tag,
-            Target.region(region).timeout(match_timeout).stitch_content(stitch_content),
+            Target.region(region).timeout(match_timeout).fully(stitch_content),
+        )
+
+    def check_element(
+        self,
+        element,  # type: Union[Text,List,Tuple,WebElement,EyesWebElement]
+        tag=None,  # type: Optional[Text]
+        match_timeout=-1,  # type: int
+    ):
+        # type: (...) -> MatchResult
+        """
+        Takes a snapshot of the given region from the browser using the web driver
+        and matches it with the expected output. If the current context is a frame,
+        the region is offsetted relative to the frame.
+
+        :param element: The element to check.
+        :param tag: Description of the visual validation checkpoint.
+        :param match_timeout: Timeout for the visual validation checkpoint
+                              (milliseconds).
+        """
+        logger.debug("check_region('%s')" % tag)
+        return self.check(
+            tag,
+            Target.region(element).timeout(match_timeout).fully(),
         )
 
     def check_region_in_frame(
@@ -467,7 +512,6 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
         :param match_timeout: Timeout for the visual validation checkpoint
                               (milliseconds).
         :param stitch_content: If `True`, stitch the internal content of the region
-        :return: None
         """
         if self.configure.is_disabled:
             logger.info("check_region_in_frame_by_selector(): ignored (disabled)")
@@ -503,6 +547,7 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
         if self.configure.is_disabled:
             logger.info("open(): ignored (disabled)")
             return
+
         if app_name:
             self.configure.app_name = app_name
         if test_name:
@@ -600,6 +645,13 @@ class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
         else:
             self._driver = EyesWebDriver(driver, self)
 
+        if self._driver.is_mobile_app and not isinstance(driver, AppiumWebDriver):
+            logger.error("To test a mobile app you need to use appium webdriver")
+            if Feature.SCALE_MOBILE_APP in self.configure.features:
+                raise EyesError(
+                    "For mobile app testing the appium driver should be used"
+                )
+
     def _init_locator_provider(self):
         self._visual_locators_provider = SeleniumVisualLocatorsProvider(
             self._driver, self._selenium_eyes
